import os, typer
from pathlib import Path
from dotenv import load_dotenv

import sys
sys.path.append('.')

load_dotenv('.env')

class DBSettings:
	
    MYSQL_HOST = os.environ.get("MYSQL_HOST")
    MYSQL_DB_NAME  = os.environ.get("MYSQL_DB_NAME")
    MYSQL_USERNAME = os.environ.get("MYSQL_USERNAME")
    MYSQL_PASSWORD = os.environ.get("MYSQL_PASSWORD")
    
    DATABASE_URL = f"mysql+pymysql://{MYSQL_USERNAME}:{MYSQL_PASSWORD}@{MYSQL_HOST}:3306/{MYSQL_DB_NAME}"


class Config:
    
    APP_NAME = os.environ.get("APP_NAME")
    APP_DIR = typer.get_app_dir(APP_NAME)
    APP_PATH = Path(APP_DIR)
    APP_CACHE_PATH = Path(APP_DIR) / "team_id_cache.json"
    

configs = Config()
settings = DBSettings()


import os
from dotenv import load_dotenv
from slack_sdk import WebClient
from sqlalchemy.orm import Session

import sys
sys.path.append('.')

import sigan.src.persistence.models as models


load_dotenv('.env')


def create_alarm(db: Session, alarm: dict):
    new_alarm = models.Alarm(**alarm)
    
    db.add(new_alarm)
    db.commit()
    db.refresh(new_alarm)
    
    return {"success": True, "new_alarm": new_alarm}


def delete_alarm(db: Session, alarm_obj):

    db.delete(alarm_obj)
    db.commit()
    
    return {"success": True}


def change_content(db: Session, change_alarm: dict, alarm_obj):
    
    setattr(alarm_obj, 'content', change_alarm['content'])
    setattr(alarm_obj, 'scheduled_message_id', change_alarm['scheduled_message_id'])
    db.commit()
    
    return {"success": True}


def change_deadline(db: Session, change_alarm: dict, alarm_obj):
    
    setattr(alarm_obj, 'deadline', change_alarm['deadline'])
    setattr(alarm_obj, 'scheduled_message_id', change_alarm['scheduled_message_id'])
    db.commit()
    
    return {"success": True}


def change_date(db: Session, change_alarm: dict, alarm_obj):
    
    setattr(alarm_obj, 'alarm_date',change_alarm['alarm_date'])
    setattr(alarm_obj, 'scheduled_message_id',change_alarm['scheduled_message_id'])
    db.commit()
    
    return {"success": True}


def change_interval(db: Session, change_alarm: dict, alarm_obj):
    
    setattr(alarm_obj, 'interval', change_alarm['interval'])
    setattr(alarm_obj, 'scheduled_message_id', change_alarm['scheduled_message_id'])
    db.commit()
    
    return {"success": True}


from sqlalchemy import Column, String, Integer, ForeignKey
from sqlalchemy.orm import relationship
from sqlalchemy.sql.sqltypes import TIMESTAMP, Boolean, DateTime

import sys
sys.path.append('.')

from sigan.src.infrastructure.database import Base


class User(Base):
    __tablename__ = "user"
    
    user_id = Column(Integer, primary_key=True, autoincrement=True)
    team_id = Column(String(100), nullable=False)
    channel_id = Column(String(100), nullable=False)
    channel_name = Column(String(100), nullable=False)
    access_token = Column(String(100), nullable=True)


class Alarm(Base):
    __tablename__ = "alarm"
    
    alarm_id = Column(Integer, primary_key=True, autoincrement=True)
    user_id = Column(Integer, ForeignKey("user.user_id"), nullable=False)
    content = Column(String(300), nullable=False)
    deadline = Column(String(100), nullable=True)
    alarm_date = Column(String(100), nullable=False)
    interval = Column(String(100), nullable=True)
    scheduled_message_id = Column(String(100), nullable=True)
    slack_channel_name = Column(String(100), nullable=True)
    slack_channel_id = Column(String(100), nullable=True)
    confirm_alarm_date = Column(DateTime, nullable=True)
    sub_scheduled_message_id = Column(String(100), nullable=True)


class AlarmNotFoundException(Exception):
    def __init__(self, alarm_id):
        self.error = f"Alarm id {alarm_id} is not found."
        
        
class AlarmConditionalFalse(Exception):
    def __init__(self):
        self.error = "If there is less than 5 minutes left for the alarm to go off, it cannot be changed or deleted."


class SlackChannelNotFound(Exception):
    def __init__(self):
        self.error = "Channel does not exist or cannot be found."
        
        
class AlarmMaximumTimeLimit(Exception):
    def __init__(self):
        self.error = "You can set up a reservation message in Slack for up to 4 months."
        

class InvalidDateSetting(Exception):
    def __init__(self):
        self.error = "If the interval is set, you can only enter the time."


class InvalidIntervalSetting(Exception):
    def __init__(self):
        self.error = "You cannot set an interval for an alarm with a date and time specified."
        

class DeadlineEarlierThanAlarmSet(Exception):
    def __init__(self):
        self.error = "Cannot set a deadline earlier than the current date."
        

class DeadlineNotSet(Exception):
    def __init__(self):
        self.error = "Alarm with no deadline set."
        




def alarm_blocks(alarm: dict):
    blocks = [
		{
			"type": "header",
			"text": {
				"type": "plain_text",
				"text": "The alarm has arrived!",
				"emoji": True
			}
		},
		{
			"type": "section",
			"fields": [
         		{
					"type": "mrkdwn",
					"text": f"*Content:*\n{alarm['content']}",
				},
        	    {
					"type": "mrkdwn",
					"text": f"*Deadline:*\n{alarm['deadline']}",
				},
				{
					"type": "mrkdwn",
					"text": f"*Notification Time:*\n{alarm['alarm_date']}",
				},
				{
					"type": "mrkdwn",
					"text": f"*Interval:*\n{alarm['interval']}"
				},
			]
		},
		{
			"type": "section",
			"text": {
				"type": "plain_text",
				"text": "Are you sure you want to delete the alarm?",
				"emoji": True
			}
		},
		{
			"type": "actions",
			"elements": [
				{
					"type": "button",
					"text": {
						"type": "plain_text",
						"emoji": True,
						"text": "Check"
					},
					"style": "primary",
					"value": "click_me_123"
				},
				{
					"type": "button",
					"text": {
						"type": "plain_text",
						"emoji": True,
						"text": "Delete"
					},
					"style": "danger",
					"value": "click_me_123"
				}
			]
		}
	]
    return blocks


import shutil
from rich import box
from rich.console import Console
from rich.table import Table, Column
from rich.style import Style
from rich.text import Text
from rich.align import Align

import sigan.src.utils as global_utils
import sigan.src.commands.constants as constants
from sigan.src.config import configs


console = Console()

# def alarm_event_display
def alarm_table_display(alarm_list):
    table = Table(
        Column(header="ID", justify="center", header_style=constants.TABLE_HEADER_COLOR, style=Style(color=constants.TABLE_TEXT_COLOR)),
        Column(header="Content", justify="center", header_style=Style(color=constants.TABLE_HEADER_COLOR), style=Style(color=constants.TABLE_ALARM_CONTENT_COLOR)),
        Column(header="Deadline", justify="center", header_style=Style(color=constants.TABLE_HEADER_COLOR), style=Style(color=constants.TABLE_TEXT_COLOR)),
        Column(header="Notification Time", justify="center", header_style=Style(color=constants.TABLE_HEADER_COLOR), style=Style(color=constants.TABLE_TEXT_COLOR)),
        Column(header="Interval", justify="right", header_style=Style(color=constants.TABLE_HEADER_COLOR), style=Style(color=constants.TABLE_TEXT_COLOR)),
        box=box.HORIZONTALS,
        width=100,
        leading=-7
    )
    
    alarm_id_cache = global_utils.read_alarm_id(configs.APP_DIR)
    
    for key, value in alarm_id_cache.items():
        table.add_row(str(key),
                      str(alarm_list[int(key) - 1]['content']),
                      str(alarm_list[int(key) - 1]['deadline']),
                      str(alarm_list[int(key) - 1]['alarm_date']),
                      str(alarm_list[int(key) - 1]['interval']),
                      )
    
    return table


def center_print(text, type: str = None, wrap: bool = False):
    if type == "success":
        style = Style(
            color=constants.DISPLAY_TERMINAL_COLOR_SUCCESS_TEXT,
            bgcolor=constants.DISPLAY_TERMINAL_COLOR_SUCCESS_BACKGROUND,
        )
    elif type == "error":
        style = Style(
            color=constants.DISPLAY_TERMINAL_COLOR_ERROR_TEXT,
            bgcolor=constants.DISPLAY_TERMINAL_COLOR_ERROR_BACKGROUND,
        )
        
    if wrap:
        width = shutil.get_terminal_size().columns // 2
    else:
        width = shutil.get_terminal_size().columns
        
    content = Text(text, style=style)
    console.print(Align.center(content, style=style, width=width), height=100)


import os
from dotenv import load_dotenv
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

from sigan.src.config import settings

load_dotenv('.env')


SQLAHCEMY_DATABASE_URL = settings.DATABASE_URL

engine = create_engine(SQLAHCEMY_DATABASE_URL)
SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)
Base = declarative_base()

def get_db():
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()


import os, re, logging
from dotenv import load_dotenv
from datetime import datetime, timedelta

from slack_sdk import WebClient
from slack_sdk.errors import SlackApiError

from sqlalchemy import and_
from sqlalchemy.orm import Session

import sys
sys.path.append('.')

import sigan.src.utils as global_utils
import sigan.src.application.utils as utils
import sigan.src.application.exceptions as exceptions
import sigan.src.application.blocks as blocks
import sigan.src.persistence.models as models
import sigan.src.persistence.repositories as router
from sigan.src.config import configs



load_dotenv('.env')

# client = WebClient(token=os.environ.get('SLACK_BOT_TOKEN'))
logger = logging.getLogger(__name__)


def create_alarm(db: Session, alarm: dict):
    post_time = datetime.strptime(alarm['alarm_date'], '%Y-%m-%d %H:%M:%S')
    
    if alarm['interval']:
        alarm['alarm_date'] = alarm['alarm_date'].split(" ")[1][:5]
    
    if alarm['slack_channel_name'] == "SiganBot":
        channel_id = get_bot_channel(db, alarm['slack_channel_name'])
    else:
        channel_id = get_channel_id(db, alarm['slack_channel_name'])
        
    if channel_id is None:
        raise exceptions.SlackChannelNotFound()
    
    client = get_client(db)
    
    try:
        response = client.chat_scheduleMessage(
            channel = channel_id,
            text = alarm['content'],
            blocks = blocks.alarm_blocks(alarm),
            post_at = int(post_time.timestamp()),
        )
    except SlackApiError as e:
        return {"success": False, "error": e.response['error']}
    
    alarm['scheduled_message_id'] = response['scheduled_message_id']
    alarm['slack_channel_id'] = channel_id
    alarm['user_id'] = get_user_id(db)
    
    if alarm['confirm_alarm_date']:
        alarm['sub_scheduled_message_id'] = create_confirm_alarm(db, alarm)
    
    router.create_alarm(db, alarm)
    
    return {"success": True, "new_alarm": alarm}


def delete_alarm(db: Session, alarm_id: int):
    alarm_id_cache = global_utils.read_alarm_id(configs.APP_DIR)
    if alarm_id > len(alarm_id_cache) or alarm_id == 0:
        raise exceptions.AlarmNotFoundException(alarm_id=alarm_id)
    delete_alarm_id = alarm_id_cache[str(alarm_id)]
    
    alarm = db.query(models.Alarm).filter(models.Alarm.alarm_id==delete_alarm_id).first()    
    alarm_dict = global_utils.sql_obj_to_dict(alarm)
    
    if alarm_dict['deadline']:
        year, month, day = utils.change_deadline_to_date(alarm_dict['deadline'])
        time = alarm_dict['alarm_date']
        if re.match("^([0-9]){4}-([0-9]){1,2}-([0-9]){1,2}|([0-9]){1,2}-([0-9]){1,2} [0-9]{2}:[0-9]{2}:[0-9]{2}$", time):
            time = alarm_dict['alarm_date'].split(" ")[1][:5]

        deadline = datetime.strptime(f"{year}-{month}-{day} {time}:00", '%Y-%m-%d %H:%M:%S')
        if deadline < datetime.now():
            router.delete_alarm(db, alarm)
            return {"success": True}
    
    post_at = list_scheduled_messages(db, alarm_dict['slack_channel_id'], alarm_dict['scheduled_message_id'])
    if post_at is None:
        if alarm_dict['confirm_alarm_date']:
            delete_confirm_alarm(db, alarm_id)
        router.delete_alarm(db, alarm)
        return {"success": True}
    
    alarm_date = datetime.fromtimestamp(post_at)
    if alarm_date - timedelta(minutes=5) < datetime.now():
        raise exceptions.AlarmConditionalFalse()
    
    client = get_client(db)
    
    try:
        client.chat_deleteScheduledMessage(
            channel=alarm_dict['slack_channel_id'],
            scheduled_message_id=alarm_dict['scheduled_message_id']
        )
    except SlackApiError as e:
        return {"success": False, "error": e.response['error']}
    
    if alarm_dict['deadline']:
        delete_confirm_alarm(db, alarm_id)
    
    router.delete_alarm(db, alarm)
    
    return {"success": True}


def change_content(db: Session, change_alarm: dict):
    alarm_id_cache = global_utils.read_alarm_id(configs.APP_DIR)
    if change_alarm['alarm_id'] > len(alarm_id_cache) or change_alarm['alarm_id'] == 0:
        raise exceptions.AlarmNotFoundException(alarm_id=change_alarm['alarm_id'])
    change_alarm_id = alarm_id_cache[str(change_alarm['alarm_id'])]
    
    alarm = db.query(models.Alarm).filter(models.Alarm.alarm_id==change_alarm_id).first()   
    alarm_dict = global_utils.sql_obj_to_dict(alarm)
    
    if re.match("^[0-9]{2}:[0-9]{2}$", alarm_dict['alarm_date']):
        interval_list = alarm_dict['interval'].split(" ")
        if interval_list[0] == "every":
            interval_list = interval_list[1:]
        
        year, month, day = utils.get_date_from_shortcut(interval_list, alarm_dict['alarm_date'])
        alarm_dict['alarm_date'] = f"{year}-{month}-{day} {alarm_dict['alarm_date']}:00"
    
    alarm_dict['content'] = change_alarm['content']

    try:
        deleted_alarm = delete_alarm(db, change_alarm['alarm_id'])
        if deleted_alarm['success'] is False:
            return {"success": False, "error": deleted_alarm['error']}
        
        new_alarm = create_alarm(db, alarm_dict)
        if new_alarm['success'] is False:
            return {"success": False, "error": new_alarm['error']}
    except Exception as e:
        return {"success": False, "error": e.error}
    
    router.change_content(db, new_alarm['new_alarm'], alarm)

    return {"success": True}


def change_deadline(db: Session, change_alarm: dict):
    alarm_id_cache = global_utils.read_alarm_id(configs.APP_DIR)
    if change_alarm['alarm_id'] > len(alarm_id_cache) or change_alarm['alarm_id'] == 0:
        raise exceptions.AlarmNotFoundException(alarm_id=change_alarm['alarm_id'])
    change_alarm_id = alarm_id_cache[str(change_alarm['alarm_id'])]
    
    alarm = db.query(models.Alarm).filter(models.Alarm.alarm_id==change_alarm_id).first()
    alarm_dict = global_utils.sql_obj_to_dict(alarm)
    
    if alarm_dict['deadline'] is None:
        raise exceptions.DeadlineNotSet()
    
    cur_deadline_year, cur_deadline_month, cur_deadline_day = utils.change_deadline_to_date(alarm_dict['deadline'])
    new_deadline_year, new_deadline_month, new_deadline_day = utils.change_deadline_to_date(change_alarm['deadline'])
    
    if re.match("^([0-9]){4}-([0-9]){1,2}-([0-9]){1,2}|([0-9]){1,2}-([0-9]){1,2} [0-9]{2}:[0-9]{2}:[0-9]{2}$", alarm_dict['alarm_date']):
        alarm_time = alarm_dict['alarm_date'].split(" ")[1][:5]
        cur_deadline_date = datetime.strptime(f"{cur_deadline_year}-{cur_deadline_month}-{cur_deadline_day} {alarm_time}:00", '%Y-%m-%d %H:%M:%S')
        new_deadline_date = datetime.strptime(f"{new_deadline_year}-{new_deadline_month}-{new_deadline_day} {alarm_time}:00", '%Y-%m-%d %H:%M:%S')
        cur_alarm_date = datetime.strptime(alarm_dict['alarm_date'], '%Y-%m-%d %H:%M:%S')

    elif re.match("^[0-9]{2}:[0-9]{2}$", alarm_dict['alarm_date']):
        interval_list = alarm_dict['interval'].split(" ")
        if interval_list[0] == "every":
            interval_list = interval_list[1:]
        
        year, month, day = utils.get_date_from_shortcut(interval_list, alarm_dict['alarm_date'])
        alarm_date = f"{year}-{month}-{day} {alarm_dict['alarm_date']}:00"
        
        cur_deadline_date = datetime.strptime(f"{cur_deadline_year}-{cur_deadline_month}-{cur_deadline_day} {alarm_dict['alarm_date']}:00", '%Y-%m-%d %H:%M:%S')
        new_deadline_date = datetime.strptime(f"{new_deadline_year}-{new_deadline_month}-{new_deadline_day} {alarm_dict['alarm_date']}:00", '%Y-%m-%d %H:%M:%S')
        cur_alarm_date = datetime.strptime(alarm_date, '%Y-%m-%d %H:%M:%S')
        
        alarm_dict['alarm_date'] = alarm_date
    
    if new_deadline_date < cur_alarm_date:
        raise exceptions.DeadlineEarlierThanAlarmSet()
    
    confirm_alarm_day = alarm_dict['confirm_alarm_date'] - cur_deadline_date
    alarm_dict['confirm_alarm_date'] = new_deadline_date + confirm_alarm_day
    alarm_dict['deadline'] = change_alarm['deadline']
    
    try:
        deleted_alarm = delete_alarm(db, change_alarm['alarm_id'])
        if deleted_alarm['success'] is False:
            return {"success": False, "error": deleted_alarm['error']} 
        
        new_alarm = create_alarm(db, alarm_dict)
        if new_alarm['success'] is False:
            return {"success": False, "error": new_alarm['error']}       
    except Exception as e:
        return {"success": False, "error": e.error}
    
    router.change_deadline(db, new_alarm['new_alarm'], alarm)

    return {"success": True}


def change_date(db: Session, change_alarm: dict):
    alarm_id_cache = global_utils.read_alarm_id(configs.APP_DIR)
    change_alarm_id = alarm_id_cache[str(change_alarm['alarm_id'])]
    
    alarm = db.query(models.Alarm).filter(models.Alarm.alarm_id==change_alarm_id).first()    
    alarm_dict = global_utils.sql_obj_to_dict(alarm)
    
    if alarm_dict['interval']:
        if not re.match("^[0-9]{2}:[0-9]{2}$", change_alarm['alarm_date']):
            raise exceptions.InvalidDateSetting()
        
        interval_list = alarm_dict['interval'].split(" ")
        if interval_list[0] == "every":
            interval_list = interval_list[1:]
            
        year, month, day = utils.get_date_from_shortcut(interval_list, change_alarm['alarm_date'])
        alarm_date = f"{year}-{month}-{day} {change_alarm['alarm_date']}:00"
    else:
        # 시간만 변경하고자 하는 경우
        if re.match("^[0-9]{2}:[0-9]{2}$", change_alarm['alarm_date']):
            current_date = alarm_dict['alarm_date'].split(" ")[0]
            alarm_date = f"{current_date} {change_alarm['alarm_date']}:00"
        # 날짜만 변경하고자 하는 경우
        elif re.match("^([0-9]){4}-([0-9]){1,2}-([0-9]){1,2}$", change_alarm['alarm_date']):
            alarm_time = alarm_dict['alarm_date'].split(" ")[1]
            alarm_date = f"{change_alarm['alarm_date']} {alarm_time}"
        # 날짜와 시간 모두 변경하고자 하는 경우
        elif re.match("^([0-9]){4}-([0-9]){1,2}-([0-9]){1,2} [0-9]{2}:[0-9]{2}:[0-9]{2}$", change_alarm['alarm_date']):
            alarm_date = change_alarm['alarm_date']
    
    alarm_dict['alarm_date'] = alarm_date
    
    try:
        deleted_alarm = delete_alarm(db, change_alarm['alarm_id'])
        if deleted_alarm['success'] is False:
            return {"success": False, "error": deleted_alarm['error']} 
        
        new_alarm = create_alarm(db, alarm_dict)
        if new_alarm['success'] is False:
            return {"success": False, "error": new_alarm['error']}       
    except Exception as e:
        return {"success": False, "error": e.error}
    
    router.change_date(db, new_alarm['new_alarm'], alarm)

    return {"success": True}


def change_interval(db: Session, change_alarm: dict):
    alarm_id_cache = global_utils.read_alarm_id(configs.APP_DIR)
    change_alarm_id = alarm_id_cache[str(change_alarm['alarm_id'])]
    
    alarm = db.query(models.Alarm).filter(models.Alarm.alarm_id==change_alarm_id).first()    
    alarm_dict = global_utils.sql_obj_to_dict(alarm)
    
    if re.match("^([0-9]){4}-([0-9]){1,2}-([0-9]){1,2} [0-9]{2}:[0-9]{2}:[0-9]{2}$", alarm_dict['alarm_date']):
        raise exceptions.InvalidIntervalSetting()
    
    interval_list = change_alarm['interval'].split(" ")
    if interval_list[0] == "every":
        interval_list = interval_list[1:]
    
    year, month, day = utils.get_date_from_shortcut(interval_list, alarm_dict['alarm_date'])
    alarm_date = f"{year}-{month}-{day} {alarm_dict['alarm_date']}:00"
    
    alarm_dict['alarm_date'] = alarm_date
    alarm_dict['interval'] = change_alarm['interval']
    
    try:
        deleted_alarm = delete_alarm(db, change_alarm['alarm_id'])
        if deleted_alarm['success'] is False:
            return {"success": False, "error": deleted_alarm['error']} 
        
        new_alarm = create_alarm(db, alarm_dict)
        if new_alarm['success'] is False:
            return {"success": False, "error": new_alarm['error']}       
    except Exception as e:
        return {"success": False, "error": e.error}
    
    router.change_interval(db, new_alarm['new_alarm'], alarm)

    return {"success": True, "alarm_obj": alarm, "new_alarm_dict": new_alarm['new_alarm']}


def list_scheduled_messages(db: Session, channel_id: str, scheduled_message_id: str):
    client = get_client(db)
    response = client.chat_scheduledMessages_list(channel=channel_id)
    if response is None:
        return None
    
    for message in response['scheduled_messages']:
        if message['id'] == scheduled_message_id:
            return message['post_at']


def get_channel_id(db: Session, channel_name: str):
    client = get_client(db)
    channels = client.conversations_list(types="public_channel,private_channel")["channels"]
    for channel in channels:
        if channel["name"] == channel_name:
            return channel["id"]
    
    return None


def get_bot_channel(db: Session, channel_name: str):
    channel = db.query(models.User).filter(models.User.channel_name==channel_name).first()
    return channel.channel_id


def get_all_alarms(db: Session, user_id: int):
    alarm = db.query(models.Alarm).filter(models.Alarm.user_id==user_id).all()
    alarm_dict_list = global_utils.sql_obj_list_to_dict_list(alarm)
    
    alarm_id_cache = {}
    for i in range(len(alarm_dict_list)):
        alarm_id_cache[i + 1] = alarm_dict_list[i]['alarm_id']
         
    global_utils.cache_alarm_id(configs.APP_DIR, alarm_id_cache)
    
    return alarm_dict_list
    

def create_confirm_alarm(db: Session, alarm: dict):
    post_time = alarm['confirm_alarm_date']
    
    if alarm['slack_channel_name'] == "SiganBot":
        channel_id = get_bot_channel(db, alarm['slack_channel_name'])
    else:
        channel_id = get_channel_id(db, alarm['slack_channel_name'])
    
    client = get_client(db)
    
    response = client.chat_scheduleMessage(
        channel = channel_id,
        text = alarm['content'],
        blocks = blocks.alarm_blocks(alarm),
        post_at = int(post_time.timestamp()),
    )
    return response['scheduled_message_id']


def delete_confirm_alarm(db: Session, alarm_id: int):
    alarm_id_cache = global_utils.read_alarm_id(configs.APP_DIR)
    delete_alarm_id = alarm_id_cache[str(alarm_id)]
    
    alarm = db.query(models.Alarm).filter(models.Alarm.alarm_id==delete_alarm_id).first()
    if not alarm:
        raise exceptions.AlarmNotFoundException(alarm_id=delete_alarm_id)
    
    client = get_client(db)

    client.chat_deleteScheduledMessage(
        channel=alarm.slack_channel_id,
        scheduled_message_id=alarm.sub_scheduled_message_id
    )


def get_client(db: Session):
    slack_info = global_utils.read_team_id(configs.APP_DIR)
    user_info = db.query(models.User).filter(models.User.team_id==slack_info['team_id']).first()
    client = WebClient(token=user_info.access_token)
    return client


def get_user_id(db: Session):
    slack_info = global_utils.read_team_id(configs.APP_DIR)
    if slack_info is None:
        return None
    
    user_info = db.query(models.User).filter(models.User.team_id==slack_info['team_id']).first()
    return user_info.user_id


def match_team_id(db: Session, team_id: str):
    user = db.query(models.User).filter(models.User.team_id==team_id).first()
    if user is None:
        return None
    return user.team_id